==> eroaster-2.2.0.0.6_3.tbz: lib/eroaster/constants.py <==
"""

Some necessary constants

"""

import os

# -----------------------------------------------------------------------------
# Some default values ... usually this is ok for you ;-)

MAJOR_VERSION = 2
MINOR_VESION = 2
MICRO_VERSION = 0

RELEASE = "0.6 (pre-release)"

title = "ECLiPt Roaster"
unixname = "eroaster"
version = "Version %d.%d.%d-%s" % (MAJOR_VERSION, MINOR_VESION, MICRO_VERSION, RELEASE)
year = "1998-2003"

configdirectory = ".eroaster"                 # Directory containing configuration files
deffile = "eroasterrc"                        # Name of the main configfile
shortcutfile = "shortcuts"                    # Name containing shortcuts
tipstatusfile = "tips.status"

# Frame labels
datacd = "  Data CD "
audiocd = "  Audio CD "
imagecd = "  ISO Image "
options = " Preferences "
special = " Special "
readcd = " Read CD "
copycd = " Copy CD "

if (os.path.exists("/usr/X11R6/share/eroaster/pixmaps")):
    iconpath = "/usr/X11R6/share/eroaster/pixmaps"
else:
    iconpath = ".%spixmaps" % os.sep

if (os.path.exists("/usr/X11R6/share/locale")):
    localedir = "/usr/X11R6/share/locale"
else:
    localedir = ".%slocale" % os.sep

if (os.path.exists("/usr/X11R6/lib/eroaster/glade")):
    gladedir = "/usr/X11R6/lib/eroaster/glade"
else:
    gladedir = ".%sglade" % os.sep

frames = [datacd, audiocd, imagecd, readcd, copycd, special, options]         # List of frames

AudioCD = "Audio CD"
DataCD = "Data CD"
modeImageCD = "CD Image"
modeDataCDImage = "Data CD Image"
BlankCDAll = "Blank CD (complete)"
BlankCDMinimal = "Blank CD (minimal)"
BlankCDLast = "Blank CD (last session)"
modeCopyCD = "Copy CD"
modeReadCD = "Read CD"
modeReadAudioCD = "Read Audio CD"
modeFixateCD = "Fixate CD"
modeImageCDcdrdao = "CD Image (cdrdao)"

if (os.path.exists("/usr/X11R6/lib/eroaster/ecat.py")):
    ecat = "/usr/X11R6/lib/eroaster/ecat.py"
else:
    ecat = ".%secat.py" % os.sep

if (os.path.exists("/usr/X11R6/lib/eroaster/eroaster.shortcuts")):
    systemshortcutfile = "/usr/X11R6/lib/eroaster/eroaster.shortcuts"
else:
    systemshortcutfile = ".%seroaster.shortcuts" % os.sep

if (os.path.exists("/usr/X11R6/lib/eroaster/waitreload.py")):
    waitreload = "/usr/X11R6/lib/eroaster/waitreload.py"
else:
    waitreload = ".%swaitreload.py" % os.sep

# Constants for the different device types
deviceRecorder = 0
deviceReader = 1

# Constants for mp3 players
playerMpg123 = "mpg123"
playerXMMS = "xmms"
playerXinf = "xinf"

# Constants for wav encoders
encoderLame = ".mp3 (lame)"
encoderOggEnc = ".ogg (oggenc)"

# Miscellaneous constants
audioinfostring = "AudioFileInfo"
data_file_list = "DataFileList"
execution_thread_done = "ERoasterExecutionThreadDone"

# CDR Sizes
cdrSize650 = "650MB"
cdrSize700 = "700MB"

# Startup types for ERoaster when called from ERoaster applet
eraDataCD = "--data"
eraAudioCD = "--audio"
eraCopyCD = "--copy"
eraCDImage = "--image"

# Various tips
tips = [ "The ERoaster file sections (data and audio) support drag & drop \nfrom most common file managers. ",
         "To use ERoaster as a user different than root, \nyou have to set the suid bit on cdrecord and cdda2wav. ",
	 "ERoaster supports saving file / song manifests as projects. \nHave a look at the Project menu. ",
         "Audio tracks can easily be re-ordered by drag & drop. " ]

==> eroaster-2.2.0.0.6_10.tbz: lib/eroaster/constants.py <==
"""

Some necessary constants

"""

import os

# -----------------------------------------------------------------------------
# Some default values ... usually this is ok for you ;-)

MAJOR_VERSION = 2
MINOR_VESION = 2
MICRO_VERSION = 0

RELEASE = "0.6 (pre-release)"

title = "ECLiPt Roaster"
unixname = "eroaster"
version = "Version %d.%d.%d-%s" % (MAJOR_VERSION, MINOR_VESION, MICRO_VERSION, RELEASE)
year = "1998-2003"

configdirectory = ".eroaster"                 # Directory containing configuration files
deffile = "eroasterrc"                        # Name of the main configfile
shortcutfile = "shortcuts"                    # Name containing shortcuts
tipstatusfile = "tips.status"

# Frame labels
datacd = "  Data CD "
audiocd = "  Audio CD "
imagecd = "  ISO Image "
options = " Preferences "
special = " Special "
readcd = " Read CD "
copycd = " Copy CD "

if (os.path.exists("/usr/local/share/eroaster/pixmaps")):
    iconpath = "/usr/local/share/eroaster/pixmaps"
else:
    iconpath = ".%spixmaps" % os.sep

if (os.path.exists("/usr/local/share/locale")):
    localedir = "/usr/local/share/locale"
else:
    localedir = ".%slocale" % os.sep

if (os.path.exists("/usr/local/lib/eroaster/glade")):
    gladedir = "/usr/local/lib/eroaster/glade"
else:
    gladedir = ".%sglade" % os.sep

frames = [datacd, audiocd, imagecd, readcd, copycd, special, options]         # List of frames

AudioCD = "Audio CD"
DataCD = "Data CD"
modeImageCD = "CD Image"
modeDataCDImage = "Data CD Image"
BlankCDAll = "Blank CD (complete)"
BlankCDMinimal = "Blank CD (minimal)"
BlankCDLast = "Blank CD (last session)"
modeCopyCD = "Copy CD"
modeReadCD = "Read CD"
modeReadAudioCD = "Read Audio CD"
modeFixateCD = "Fixate CD"
modeImageCDcdrdao = "CD Image (cdrdao)"

if (os.path.exists("/usr/local/lib/eroaster/ecat.py")):
    ecat = "/usr/local/lib/eroaster/ecat.py"
else:
    ecat = ".%secat.py" % os.sep

if (os.path.exists("/usr/local/lib/eroaster/eroaster.shortcuts")):
    systemshortcutfile = "/usr/local/lib/eroaster/eroaster.shortcuts"
else:
    systemshortcutfile = ".%seroaster.shortcuts" % os.sep

if (os.path.exists("/usr/local/lib/eroaster/waitreload.py")):
    waitreload = "/usr/local/lib/eroaster/waitreload.py"
else:
    waitreload = ".%swaitreload.py" % os.sep

# Constants for the different device types
deviceRecorder = 0
deviceReader = 1

# Constants for mp3 players
playerMpg123 = "mpg123"
playerXMMS = "xmms"
playerXinf = "xinf"

# Constants for wav encoders
encoderLame = ".mp3 (lame)"
encoderOggEnc = ".ogg (oggenc)"

# Miscellaneous constants
audioinfostring = "AudioFileInfo"
data_file_list = "DataFileList"
execution_thread_done = "ERoasterExecutionThreadDone"

# CDR Sizes
cdrSize650 = "650MB"
cdrSize700 = "700MB"

# Startup types for ERoaster when called from ERoaster applet
eraDataCD = "--data"
eraAudioCD = "--audio"
eraCopyCD = "--copy"
eraCDImage = "--image"

# Various tips
tips = [ "The ERoaster file sections (data and audio) support drag & drop \nfrom most common file managers. ",
         "To use ERoaster as a user different than root, \nyou have to set the suid bit on cdrecord and cdda2wav. ",
	 "ERoaster supports saving file / song manifests as projects. \nHave a look at the Project menu. ",
         "Audio tracks can easily be re-ordered by drag & drop. " ]
